@@ -1,6 +1,8 @@
 describe.ologit<-function(){
 category <- "ordinal"
 description  <- "Ordinal Logistic Regression for Ordered Categorical Dependent Variables"
+authors <- c()
+year <- 2007
 package <-list(	name 	="MASS",
 		version	="0.1"
 		)
@@ -13,5 +15,5 @@ parameters$mu<-list(equations=c(1,1),
 			varInSpecialFunction=c(1,1)
 			)
 			
-list(category=category,description=description,package=package,parameters=parameters)
+list(category = category, authors = authors, year = year,description=description,package=package,parameters=parameters)
 }
